==> eam-wshub-proxyclient-11.4-10-sources.jar: net/datastream/schemas/mp_fields/SCREENUSERTABREPORTPARAMMAPID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour SCREENUSERTABREPORTPARAMMAPID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="SCREENUSERTABREPORTPARAMMAPID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FUNCTIONTABID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}KEYFIELDCODE"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "SCREENUSERTABREPORTPARAMMAPID_Type", propOrder = {
    "functiontabid",
    "keyfieldcode"
})
public class SCREENUSERTABREPORTPARAMMAPID_Type {

    @XmlElement(name = "FUNCTIONTABID", required = true)
    protected FUNCTIONTABID_Type functiontabid;
    @XmlElement(name = "KEYFIELDCODE", required = true)
    protected String keyfieldcode;

    /**
     * Obtient la valeur de la propriété functiontabid.
     * 
     * @return
     *     possible object is
     *     {@link FUNCTIONTABID_Type }
     *     
     */
    public FUNCTIONTABID_Type getFUNCTIONTABID() {
        return functiontabid;
    }

    /**
     * Définit la valeur de la propriété functiontabid.
     * 
     * @param value
     *     allowed object is
     *     {@link FUNCTIONTABID_Type }
     *     
     */
    public void setFUNCTIONTABID(FUNCTIONTABID_Type value) {
        this.functiontabid = value;
    }

    /**
     * Obtient la valeur de la propriété keyfieldcode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getKEYFIELDCODE() {
        return keyfieldcode;
    }

    /**
     * Définit la valeur de la propriété keyfieldcode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setKEYFIELDCODE(String value) {
        this.keyfieldcode = value;
    }

}

==> eam-wshub-proxyclient-11.7-0-sources.jar: net/datastream/schemas/mp_fields/SCREENUSERTABREPORTPARAMMAPID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for SCREENUSERTABREPORTPARAMMAPID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="SCREENUSERTABREPORTPARAMMAPID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FUNCTIONTABID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}KEYFIELDCODE"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "SCREENUSERTABREPORTPARAMMAPID_Type", propOrder = {
    "functiontabid",
    "keyfieldcode"
})
public class SCREENUSERTABREPORTPARAMMAPID_Type {

    @XmlElement(name = "FUNCTIONTABID", required = true)
    protected FUNCTIONTABID_Type functiontabid;
    @XmlElement(name = "KEYFIELDCODE", required = true)
    protected String keyfieldcode;

    /**
     * Gets the value of the functiontabid property.
     * 
     * @return
     *     possible object is
     *     {@link FUNCTIONTABID_Type }
     *     
     */
    public FUNCTIONTABID_Type getFUNCTIONTABID() {
        return functiontabid;
    }

    /**
     * Sets the value of the functiontabid property.
     * 
     * @param value
     *     allowed object is
     *     {@link FUNCTIONTABID_Type }
     *     
     */
    public void setFUNCTIONTABID(FUNCTIONTABID_Type value) {
        this.functiontabid = value;
    }

    /**
     * Gets the value of the keyfieldcode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getKEYFIELDCODE() {
        return keyfieldcode;
    }

    /**
     * Sets the value of the keyfieldcode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setKEYFIELDCODE(String value) {
        this.keyfieldcode = value;
    }

}
